import { useAjax } from "@/Hook/useAjax";
import { addOrUpdateBackPolicyApi } from "@/services/iaaSystem/backPolicy";
import { Form, Input, InputNumber, message, Modal } from "antd";
import React from "react"


interface Props {
    onChange?: () => void
    visible?: boolean
    onClose?: () => void
    initialValues?: any
}

/**
 * 新增修改回传策略
 * @returns 
 */
const ModalBackPolicy: React.FC<Props> = ({ onChange, visible, onClose, initialValues }) => {

    /*******************************/
    const [form] = Form.useForm<IAAAPI.AddOrUpdateBackPolicyProps>();

    const addOrUpdateBackPolicy = useAjax((params) => addOrUpdateBackPolicyApi(params))
    /*******************************/

    const handleOk = async () => {
        form.submit()
        let data = await form.validateFields()
        if (initialValues?.id) {
            data.id = initialValues?.id
        }
        addOrUpdateBackPolicy.run(data).then(res => {
            if (res?.data) {
                if (initialValues?.id) {
                    message.success('修改成功')
                } else {
                    message.success('新增成功')
                }
                onChange && onChange()
            }
        })
    }

    return <Modal
        title={<strong>{initialValues?.id ? '修改策略' : '新增策略'}</strong>}
        open={visible}
        onCancel={onClose}
        onOk={handleOk}
        confirmLoading={addOrUpdateBackPolicy.loading}
    >
        <Form
            name="basicBackPolicy"
            layout="vertical"
            form={form}
            autoComplete="off"
            colon={false}
            initialValues={{ ...initialValues }}
        >
            <Form.Item label={<strong>策略名称</strong>} name="backPolicyName" rules={[{ required: true, message: '请输入策略名称!' }]}>
                <Input min={0} placeholder="请输入策略名称" />
            </Form.Item>
            <Form.Item label={<strong>广告观看次数</strong>} name="ipu">
                <InputNumber min={0} placeholder="请输入广告观看次数" style={{ minWidth: 472 }} />
            </Form.Item>
            <Form.Item label={<strong>广告千次收益(分)</strong>} name="ecpm">
                <InputNumber min={0} placeholder="请输入广告千次收益" style={{ minWidth: 472 }} />
            </Form.Item>
            <Form.Item label={<strong>广告总收益(分)</strong>} name="costTotal">
                <InputNumber min={0} placeholder="请输入广告千次收益" style={{ minWidth: 472 }} />
            </Form.Item>
            <Form.Item label={<strong>有效窗口时间(分钟)</strong>} name="validWindowTime">
                <InputNumber min={0} placeholder="请输入广告千次收益" style={{ minWidth: 472 }} />
            </Form.Item>
        </Form>
    </Modal>
}

export default React.memo(ModalBackPolicy)