import ProTable, { ActionType } from "@ant-design/pro-table"
import React, { useEffect, useRef, useState } from "react"
import tableConfig from "./tableConfig"
import { useAjax } from "@/Hook/useAjax";
import { getRoleEnumApi, getRoleListApi } from "@/services/iaaSystem/power";
import { Button } from "antd";
import { PlusOutlined } from "@ant-design/icons";
import { getUserAllApi } from "@/services/user";
import { DefaultOptionType } from "antd/lib/select";
import ModalPower from "./modalPower";



/**
 * 角色分配
 */
const Power: React.FC = () => {

    /*******************************************/
    const actionRef = useRef<ActionType>();
    const [visible, setVisible] = useState<boolean>(false)
    const [initialValues, setInitialValues] = useState<any>()
    const [roleTypeList, setRoleTypeList] = useState<DefaultOptionType[]>([])
    const [roleTypeEnum, setRoleTypeEnum] = useState<any>({})
    const [userList, setUserList] = useState<DefaultOptionType[]>([])
    const [userObj, setUserObj] = useState<any>({})


    const getRoleList = useAjax((params) => getRoleListApi(params), { type: 'table' })
    const getUserAll = useAjax(() => getUserAllApi())
    const getRoleEnum = useAjax(() => getRoleEnumApi())
    /*******************************************/

    useEffect(() => {
        getUserAll.run().then(res => {
            if (res?.data) {
                let newUserList: DefaultOptionType[] = []
                let newUserObj: any = {}
                res.data.forEach((item: { nickname: any; userId: any; }) => {
                    newUserList.push({ label: item.nickname, value: item.userId })
                    newUserObj[item.userId] = {
                        text: item.nickname
                    }
                })
                setUserList(newUserList)
                setUserObj(newUserObj)
            }
        })
        getRoleEnum.run().then(res => {
            console.log(res.data)
            if (res?.data) {
                let newRoleTypeList: DefaultOptionType[] = []
                let newRoleTypeEnum: any = {}
                Object.keys(res.data).forEach(key => {
                    newRoleTypeList.push({ label: res.data[key], value: key })
                    newRoleTypeEnum[key] = {
                        text: res.data[key]
                    }
                })
                setRoleTypeList(newRoleTypeList)
                setRoleTypeEnum(newRoleTypeEnum)
            }
        })
    }, [])

    /**
     * 修改
     * @param data 
     */
    const handleEdit = (data: any) => {
        console.log(data)
        setInitialValues(data)
        setVisible(true)
    }

    return <>
        <ProTable<any>
            columns={tableConfig(handleEdit, roleTypeEnum, userObj)}
            actionRef={actionRef}
            cardBordered
            request={async (params, sort, filter) => {
                console.log(sort, filter);
                return await getRoleList.run(params)
            }}
            editable={{
                type: 'multiple',
            }}
            rowKey="userId"
            search={{
                labelWidth: 'auto',
            }}
            headerTitle={<strong>角色分配</strong>}
            toolBarRender={() => [
                <Button type="primary" onClick={() => {
                    setVisible(true)
                }}>
                    <PlusOutlined />
                    新建
                </Button>
            ]}
        />

        {/* 新增修改 */}
        {visible && <ModalPower
            initialValues={initialValues}
            roleTypeList={roleTypeList}
            userList={userList}
            visible={visible}
            onChange={() => {
                setVisible(false)
                setInitialValues(undefined)
                actionRef.current?.reload()
            }}
            onClose={() => {
                setVisible(false)
                setInitialValues(undefined)
            }}
        />}
    </>
}

export default Power